@@ -1,5 +1,4 @@
 // SPDX-FileCopyrightText: 2020 Han Young <hanyoung@protonmail.com>
-//
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #pragma once
@@ -28,7 +27,7 @@ public:
     void save();
     
     Q_INVOKABLE void addAction(QString action);
-    Q_INVOKABLE bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
+    Q_INVOKABLE bool removeRow(int row);
 
 private:
     QStringList m_actions;
